###########
User manual
###########

First of all, take a look at how to load MOLA environment and what is a Workflow in MOLA context.
Links between pages should be enough to let you discover MOLA from that. 

.. toctree::
   :maxdepth: 1

   environment
   workflow/introduction
   workflow/inputs
   workflow/boundary_conditions
   workflow/workflows_by_application/index
   workflow/manager
   workflow/debug
   commands